You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2015/02/16 23:40:42 UTC

[72/82] [math] Update for next development iteration: commons-math4

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializer.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializer.java
index 1f48d45..0525b47 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializer.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializer.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet;
+package org.apache.commons.math4.ml.neuralnet;
 
 /**
  * Defines how to assign the first value of a neuron's feature.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializerFactory.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializerFactory.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializerFactory.java
index f5569b1..1521a60 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializerFactory.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/FeatureInitializerFactory.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet;
+package org.apache.commons.math4.ml.neuralnet;
 
-import org.apache.commons.math3.distribution.RealDistribution;
-import org.apache.commons.math3.distribution.UniformRealDistribution;
-import org.apache.commons.math3.analysis.UnivariateFunction;
-import org.apache.commons.math3.analysis.function.Constant;
-import org.apache.commons.math3.random.RandomGenerator;
+import org.apache.commons.math4.analysis.UnivariateFunction;
+import org.apache.commons.math4.analysis.function.Constant;
+import org.apache.commons.math4.distribution.RealDistribution;
+import org.apache.commons.math4.distribution.UniformRealDistribution;
+import org.apache.commons.math4.random.RandomGenerator;
 
 /**
  * Creates functions that will select the initial values of a neuron's
@@ -42,7 +42,7 @@ public class FeatureInitializerFactory {
      * uniform distribution.
      * @return an initializer such that the features will be initialized with
      * values within the given range.
-     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException
+     * @throws org.apache.commons.math4.exception.NumberIsTooLargeException
      * if {@code min >= max}.
      */
     public static FeatureInitializer uniform(final RandomGenerator rng,
@@ -59,7 +59,7 @@ public class FeatureInitializerFactory {
      * @param max Upper bound of the range.
      * @return an initializer such that the features will be initialized with
      * values within the given range.
-     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException
+     * @throws org.apache.commons.math4.exception.NumberIsTooLargeException
      * if {@code min >= max}.
      */
     public static FeatureInitializer uniform(final double min,

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/MapUtils.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/MapUtils.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/MapUtils.java
index 9e67982..a80b0a3 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/MapUtils.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/MapUtils.java
@@ -15,14 +15,15 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet;
+package org.apache.commons.math4.ml.neuralnet;
 
 import java.util.HashMap;
 import java.util.Collection;
-import org.apache.commons.math3.ml.distance.DistanceMeasure;
-import org.apache.commons.math3.ml.neuralnet.twod.NeuronSquareMesh2D;
-import org.apache.commons.math3.exception.NoDataException;
-import org.apache.commons.math3.util.Pair;
+
+import org.apache.commons.math4.exception.NoDataException;
+import org.apache.commons.math4.ml.distance.DistanceMeasure;
+import org.apache.commons.math4.ml.neuralnet.twod.NeuronSquareMesh2D;
+import org.apache.commons.math4.util.Pair;
 
 /**
  * Utilities for network maps.
@@ -44,7 +45,7 @@ public class MapUtils {
      * @param distance Distance function. The neuron's features are
      * passed as the first argument to {@link DistanceMeasure#compute(double[],double[])}.
      * @return the neuron whose features are closest to the given data.
-     * @throws org.apache.commons.math3.exception.DimensionMismatchException
+     * @throws org.apache.commons.math4.exception.DimensionMismatchException
      * if the size of the input is not compatible with the neurons features
      * size.
      */
@@ -73,7 +74,7 @@ public class MapUtils {
      * @param distance Distance function. The neuron's features are
      * passed as the first argument to {@link DistanceMeasure#compute(double[],double[])}.
      * @return the two neurons whose features are closest to the given data.
-     * @throws org.apache.commons.math3.exception.DimensionMismatchException
+     * @throws org.apache.commons.math4.exception.DimensionMismatchException
      * if the size of the input is not compatible with the neurons features
      * size.
      */

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/Network.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/Network.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/Network.java
index 6c4b8e9..89d335f 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/Network.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/Network.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet;
+package org.apache.commons.math4.ml.neuralnet;
 
 import java.io.Serializable;
 import java.io.ObjectInputStream;
@@ -30,8 +30,9 @@ import java.util.Comparator;
 import java.util.Collections;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicLong;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathIllegalStateException;
+
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalStateException;
 
 /**
  * Neural network, composed of {@link Neuron} instances and the links

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/Neuron.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/Neuron.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/Neuron.java
index 51c533f..0f58b3a 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/Neuron.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/Neuron.java
@@ -15,13 +15,14 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet;
+package org.apache.commons.math4.ml.neuralnet;
 
 import java.io.Serializable;
 import java.io.ObjectInputStream;
 import java.util.concurrent.atomic.AtomicReference;
-import org.apache.commons.math3.util.Precision;
-import org.apache.commons.math3.exception.DimensionMismatchException;
+
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.util.Precision;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/SquareNeighbourhood.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/SquareNeighbourhood.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/SquareNeighbourhood.java
index a3c0d95..4f2c175 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/SquareNeighbourhood.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/SquareNeighbourhood.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet;
+package org.apache.commons.math4.ml.neuralnet;
 
 /**
  * Defines neighbourhood types.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/UpdateAction.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/UpdateAction.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/UpdateAction.java
index 041d3d6..862a3f2 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/UpdateAction.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/UpdateAction.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet;
+package org.apache.commons.math4.ml.neuralnet;
 
 /**
  * Describes how to update the network in response to a training

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/NeuronString.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/NeuronString.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/NeuronString.java
index 747a925..94aff98 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/NeuronString.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/NeuronString.java
@@ -15,14 +15,15 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.oned;
+package org.apache.commons.math4.ml.neuralnet.oned;
 
 import java.io.Serializable;
 import java.io.ObjectInputStream;
-import org.apache.commons.math3.ml.neuralnet.Network;
-import org.apache.commons.math3.ml.neuralnet.FeatureInitializer;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.OutOfRangeException;
+
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.ml.neuralnet.FeatureInitializer;
+import org.apache.commons.math4.ml.neuralnet.Network;
 
 /**
  * Neural network with the topology of a one-dimensional line.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/package-info.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/package-info.java
index 0b47fae..b95b8be 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/package-info.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/oned/package-info.java
@@ -19,4 +19,4 @@
  * One-dimensional neural networks.
  */
 
-package org.apache.commons.math3.ml.neuralnet.oned;
+package org.apache.commons.math4.ml.neuralnet.oned;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/package-info.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/package-info.java
index d8e907e..d2a79c4 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/package-info.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/package-info.java
@@ -19,4 +19,4 @@
  * Neural networks.
  */
 
-package org.apache.commons.math3.ml.neuralnet;
+package org.apache.commons.math4.ml.neuralnet;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenTrainingTask.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenTrainingTask.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenTrainingTask.java
index 9aa497d..0e0fcab 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenTrainingTask.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenTrainingTask.java
@@ -15,10 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm;
+package org.apache.commons.math4.ml.neuralnet.sofm;
 
 import java.util.Iterator;
-import org.apache.commons.math3.ml.neuralnet.Network;
+
+import org.apache.commons.math4.ml.neuralnet.Network;
 
 /**
  * Trainer for Kohonen's Self-Organizing Map.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenUpdateAction.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenUpdateAction.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenUpdateAction.java
index 91587bf..f09ed24 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenUpdateAction.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/KohonenUpdateAction.java
@@ -15,18 +15,19 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm;
+package org.apache.commons.math4.ml.neuralnet.sofm;
 
 import java.util.Collection;
 import java.util.HashSet;
 import java.util.concurrent.atomic.AtomicLong;
-import org.apache.commons.math3.ml.neuralnet.Network;
-import org.apache.commons.math3.ml.neuralnet.MapUtils;
-import org.apache.commons.math3.ml.neuralnet.Neuron;
-import org.apache.commons.math3.ml.neuralnet.UpdateAction;
-import org.apache.commons.math3.ml.distance.DistanceMeasure;
-import org.apache.commons.math3.linear.ArrayRealVector;
-import org.apache.commons.math3.analysis.function.Gaussian;
+
+import org.apache.commons.math4.analysis.function.Gaussian;
+import org.apache.commons.math4.linear.ArrayRealVector;
+import org.apache.commons.math4.ml.distance.DistanceMeasure;
+import org.apache.commons.math4.ml.neuralnet.MapUtils;
+import org.apache.commons.math4.ml.neuralnet.Network;
+import org.apache.commons.math4.ml.neuralnet.Neuron;
+import org.apache.commons.math4.ml.neuralnet.UpdateAction;
 
 /**
  * Update formula for <a href="http://en.wikipedia.org/wiki/Kohonen">

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunction.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunction.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunction.java
index ba9d152..a13b2cf 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunction.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunction.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm;
+package org.apache.commons.math4.ml.neuralnet.sofm;
 
 /**
  * Provides the learning rate as a function of the number of calls

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunctionFactory.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunctionFactory.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunctionFactory.java
index 9165e82..0371475 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunctionFactory.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/LearningFactorFunctionFactory.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm;
+package org.apache.commons.math4.ml.neuralnet.sofm;
 
-import org.apache.commons.math3.ml.neuralnet.sofm.util.ExponentialDecayFunction;
-import org.apache.commons.math3.ml.neuralnet.sofm.util.QuasiSigmoidDecayFunction;
-import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.ml.neuralnet.sofm.util.ExponentialDecayFunction;
+import org.apache.commons.math4.ml.neuralnet.sofm.util.QuasiSigmoidDecayFunction;
 
 /**
  * Factory for creating instances of {@link LearningFactorFunction}.
@@ -45,13 +45,13 @@ public class LearningFactorFunctionFactory {
      * @param numCall Argument for which the function returns
      * {@code valueAtNumCall}.
      * @return the learning factor function.
-     * @throws org.apache.commons.math3.exception.OutOfRangeException
+     * @throws org.apache.commons.math4.exception.OutOfRangeException
      * if {@code initValue <= 0} or {@code initValue > 1}.
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      * if {@code valueAtNumCall <= 0}.
-     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException
+     * @throws org.apache.commons.math4.exception.NumberIsTooLargeException
      * if {@code valueAtNumCall >= initValue}.
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      * if {@code numCall <= 0}.
      */
     public static LearningFactorFunction exponentialDecay(final double initValue,
@@ -88,11 +88,11 @@ public class LearningFactorFunctionFactory {
      * @param slope Value of the function derivative at {@code numCall}.
      * @param numCall Inflexion point.
      * @return the learning factor function.
-     * @throws org.apache.commons.math3.exception.OutOfRangeException
+     * @throws org.apache.commons.math4.exception.OutOfRangeException
      * if {@code initValue <= 0} or {@code initValue > 1}.
-     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException
+     * @throws org.apache.commons.math4.exception.NumberIsTooLargeException
      * if {@code slope >= 0}.
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      * if {@code numCall <= 0}.
      */
     public static LearningFactorFunction quasiSigmoidDecay(final double initValue,

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunction.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunction.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunction.java
index 68149f7..d379f0f 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunction.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunction.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm;
+package org.apache.commons.math4.ml.neuralnet.sofm;
 
 /**
  * Provides the network neighbourhood's size as a function of the

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunctionFactory.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunctionFactory.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunctionFactory.java
index bdbfa2f..e87a973 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunctionFactory.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/NeighbourhoodSizeFunctionFactory.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm;
+package org.apache.commons.math4.ml.neuralnet.sofm;
 
-import org.apache.commons.math3.ml.neuralnet.sofm.util.ExponentialDecayFunction;
-import org.apache.commons.math3.ml.neuralnet.sofm.util.QuasiSigmoidDecayFunction;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.ml.neuralnet.sofm.util.ExponentialDecayFunction;
+import org.apache.commons.math4.ml.neuralnet.sofm.util.QuasiSigmoidDecayFunction;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Factory for creating instances of {@link NeighbourhoodSizeFunction}.
@@ -45,13 +45,13 @@ public class NeighbourhoodSizeFunctionFactory {
      * @param numCall Argument for which the function returns
      * {@code valueAtNumCall}.
      * @return the neighbourhood size function.
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      * if {@code initValue <= 0}.
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      * if {@code valueAtNumCall <= 0}.
-     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException
+     * @throws org.apache.commons.math4.exception.NumberIsTooLargeException
      * if {@code valueAtNumCall >= initValue}.
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      * if {@code numCall <= 0}.
      */
     public static NeighbourhoodSizeFunction exponentialDecay(final double initValue,
@@ -83,11 +83,11 @@ public class NeighbourhoodSizeFunctionFactory {
      * @param slope Value of the function derivative at {@code numCall}.
      * @param numCall Inflexion point.
      * @return the neighbourhood size function.
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      * if {@code initValue <= 0}.
-     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException
+     * @throws org.apache.commons.math4.exception.NumberIsTooLargeException
      * if {@code slope >= 0}.
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      * if {@code numCall <= 0}.
      */
     public static NeighbourhoodSizeFunction quasiSigmoidDecay(final double initValue,

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/package-info.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/package-info.java
index 60c3c61..fec9d90 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/package-info.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/package-info.java
@@ -19,4 +19,4 @@
  * Self Organizing Feature Map.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm;
+package org.apache.commons.math4.ml.neuralnet.sofm;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/ExponentialDecayFunction.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/ExponentialDecayFunction.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/ExponentialDecayFunction.java
index 19e7380..d914bf1 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/ExponentialDecayFunction.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/ExponentialDecayFunction.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm.util;
+package org.apache.commons.math4.ml.neuralnet.sofm.util;
 
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
-import org.apache.commons.math3.exception.NumberIsTooLargeException;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.NumberIsTooLargeException;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Exponential decay function: <code>a e<sup>-x / b</sup></code>,

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/QuasiSigmoidDecayFunction.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/QuasiSigmoidDecayFunction.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/QuasiSigmoidDecayFunction.java
index 3d35c17..4abef6f 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/QuasiSigmoidDecayFunction.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/QuasiSigmoidDecayFunction.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm.util;
+package org.apache.commons.math4.ml.neuralnet.sofm.util;
 
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
-import org.apache.commons.math3.exception.NumberIsTooLargeException;
-import org.apache.commons.math3.analysis.function.Logistic;
+import org.apache.commons.math4.analysis.function.Logistic;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.NumberIsTooLargeException;
 
 /**
  * Decay function whose shape is similar to a sigmoid.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/package-info.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/package-info.java
index 5078ed2..8da688b 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/package-info.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/sofm/util/package-info.java
@@ -19,4 +19,4 @@
  * Miscellaneous utilities.
  */
 
-package org.apache.commons.math3.ml.neuralnet.sofm.util;
+package org.apache.commons.math4.ml.neuralnet.sofm.util;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/NeuronSquareMesh2D.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/NeuronSquareMesh2D.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/NeuronSquareMesh2D.java
index ce30d86..a6f4315 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/NeuronSquareMesh2D.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/NeuronSquareMesh2D.java
@@ -15,19 +15,20 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ml.neuralnet.twod;
+package org.apache.commons.math4.ml.neuralnet.twod;
 
 import java.util.List;
 import java.util.ArrayList;
 import java.io.Serializable;
 import java.io.ObjectInputStream;
-import org.apache.commons.math3.ml.neuralnet.Neuron;
-import org.apache.commons.math3.ml.neuralnet.Network;
-import org.apache.commons.math3.ml.neuralnet.FeatureInitializer;
-import org.apache.commons.math3.ml.neuralnet.SquareNeighbourhood;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.OutOfRangeException;
-import org.apache.commons.math3.exception.MathInternalError;
+
+import org.apache.commons.math4.exception.MathInternalError;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.ml.neuralnet.FeatureInitializer;
+import org.apache.commons.math4.ml.neuralnet.Network;
+import org.apache.commons.math4.ml.neuralnet.Neuron;
+import org.apache.commons.math4.ml.neuralnet.SquareNeighbourhood;
 
 /**
  * Neural network with the topology of a two-dimensional surface.
@@ -37,7 +38,7 @@ import org.apache.commons.math3.exception.MathInternalError;
  * <a href="http://en.wikipedia.org/wiki/Kohonen">
  *  Self Organizing Feature Map</a>.
  *
- * @see org.apache.commons.math3.ml.neuralnet.sofm
+ * @see org.apache.commons.math4.ml.neuralnet.sofm
  * @since 3.3
  */
 public class NeuronSquareMesh2D implements Serializable {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/package-info.java b/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/package-info.java
index 41535e8..f491843 100644
--- a/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/package-info.java
+++ b/src/main/java/org/apache/commons/math4/ml/neuralnet/twod/package-info.java
@@ -19,4 +19,4 @@
  * Two-dimensional neural networks.
  */
 
-package org.apache.commons.math3.ml.neuralnet.twod;
+package org.apache.commons.math4.ml.neuralnet.twod;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ml/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ml/package-info.java b/src/main/java/org/apache/commons/math4/ml/package-info.java
index 80ae917..f0a6e9d 100644
--- a/src/main/java/org/apache/commons/math4/ml/package-info.java
+++ b/src/main/java/org/apache/commons/math4/ml/package-info.java
@@ -17,4 +17,4 @@
 /**
  * Base package for machine learning algorithms.
  */
-package org.apache.commons.math3.ml;
+package org.apache.commons.math4.ml;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/AbstractIntegrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/AbstractIntegrator.java b/src/main/java/org/apache/commons/math4/ode/AbstractIntegrator.java
index fd170c1..9d23fe2 100644
--- a/src/main/java/org/apache/commons/math4/ode/AbstractIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/AbstractIntegrator.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -26,20 +26,20 @@ import java.util.List;
 import java.util.SortedSet;
 import java.util.TreeSet;
 
-import org.apache.commons.math3.analysis.solvers.BracketingNthOrderBrentSolver;
-import org.apache.commons.math3.analysis.solvers.UnivariateSolver;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NoBracketingException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.ode.events.EventHandler;
-import org.apache.commons.math3.ode.events.EventState;
-import org.apache.commons.math3.ode.sampling.AbstractStepInterpolator;
-import org.apache.commons.math3.ode.sampling.StepHandler;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.Incrementor;
-import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math4.analysis.solvers.BracketingNthOrderBrentSolver;
+import org.apache.commons.math4.analysis.solvers.UnivariateSolver;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NoBracketingException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.ode.events.EventHandler;
+import org.apache.commons.math4.ode.events.EventState;
+import org.apache.commons.math4.ode.sampling.AbstractStepInterpolator;
+import org.apache.commons.math4.ode.sampling.StepHandler;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.Incrementor;
+import org.apache.commons.math4.util.Precision;
 
 /**
  * Base class managing common boilerplate for all integrators.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/AbstractParameterizable.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/AbstractParameterizable.java b/src/main/java/org/apache/commons/math4/ode/AbstractParameterizable.java
index d6beff4..baa5cbb 100644
--- a/src/main/java/org/apache/commons/math4/ode/AbstractParameterizable.java
+++ b/src/main/java/org/apache/commons/math4/ode/AbstractParameterizable.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.util.ArrayList;
 import java.util.Collection;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/ContinuousOutputModel.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/ContinuousOutputModel.java b/src/main/java/org/apache/commons/math4/ode/ContinuousOutputModel.java
index 75e4979..de3d6c4 100644
--- a/src/main/java/org/apache/commons/math4/ode/ContinuousOutputModel.java
+++ b/src/main/java/org/apache/commons/math4/ode/ContinuousOutputModel.java
@@ -15,19 +15,19 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.ode.sampling.StepHandler;
-import org.apache.commons.math3.ode.sampling.StepInterpolator;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.ode.sampling.StepHandler;
+import org.apache.commons.math4.ode.sampling.StepInterpolator;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * This class stores all information provided by an ODE integrator
@@ -78,7 +78,7 @@ import org.apache.commons.math3.util.FastMath;
  * ContinuousOutputModel instance can be important if the state vector
  * is large, if the integration interval is long or if the steps are
  * small (which can result from small tolerance settings in {@link
- * org.apache.commons.math3.ode.nonstiff.AdaptiveStepsizeIntegrator adaptive
+ * org.apache.commons.math4.ode.nonstiff.AdaptiveStepsizeIntegrator adaptive
  * step size integrators}).</p>
  *
  * @see StepHandler
@@ -376,8 +376,8 @@ public class ContinuousOutputModel
    * to be preserved across several calls to the associated
    * {@link #setInterpolatedTime(double)} method.</p>
    * @param secondaryStateIndex index of the secondary set, as returned by {@link
-   * org.apache.commons.math3.ode.ExpandableStatefulODE#addSecondaryEquations(
-   * org.apache.commons.math3.ode.SecondaryEquations)
+   * org.apache.commons.math4.ode.ExpandableStatefulODE#addSecondaryEquations(
+   * org.apache.commons.math4.ode.SecondaryEquations)
    * ExpandableStatefulODE.addSecondaryEquations(SecondaryEquations)}
    * @return interpolated secondary state at the current interpolation date
    * @see #setInterpolatedTime(double)
@@ -398,8 +398,8 @@ public class ContinuousOutputModel
    * to be preserved across several calls to the associated
    * {@link #setInterpolatedTime(double)} method.</p>
    * @param secondaryStateIndex index of the secondary set, as returned by {@link
-   * org.apache.commons.math3.ode.ExpandableStatefulODE#addSecondaryEquations(
-   * org.apache.commons.math3.ode.SecondaryEquations)
+   * org.apache.commons.math4.ode.ExpandableStatefulODE#addSecondaryEquations(
+   * org.apache.commons.math4.ode.SecondaryEquations)
    * ExpandableStatefulODE.addSecondaryEquations(SecondaryEquations)}
    * @return interpolated secondary derivatives at the current interpolation date
    * @see #setInterpolatedTime(double)

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/EquationsMapper.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/EquationsMapper.java b/src/main/java/org/apache/commons/math4/ode/EquationsMapper.java
index 85b94c8..29fbd35 100644
--- a/src/main/java/org/apache/commons/math4/ode/EquationsMapper.java
+++ b/src/main/java/org/apache/commons/math4/ode/EquationsMapper.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
 
 /**
  * Class mapping the part of a complete state or derivative that pertains

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/ExpandableStatefulODE.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/ExpandableStatefulODE.java b/src/main/java/org/apache/commons/math4/ode/ExpandableStatefulODE.java
index dc7d4a9..711f524 100644
--- a/src/main/java/org/apache/commons/math4/ode/ExpandableStatefulODE.java
+++ b/src/main/java/org/apache/commons/math4/ode/ExpandableStatefulODE.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/FirstOrderConverter.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/FirstOrderConverter.java b/src/main/java/org/apache/commons/math4/ode/FirstOrderConverter.java
index 2252619..d59c9bb 100644
--- a/src/main/java/org/apache/commons/math4/ode/FirstOrderConverter.java
+++ b/src/main/java/org/apache/commons/math4/ode/FirstOrderConverter.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 
 /** This class converts second order differential equations to first

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/FirstOrderDifferentialEquations.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/FirstOrderDifferentialEquations.java b/src/main/java/org/apache/commons/math4/ode/FirstOrderDifferentialEquations.java
index db1a21b..11c7997 100644
--- a/src/main/java/org/apache/commons/math4/ode/FirstOrderDifferentialEquations.java
+++ b/src/main/java/org/apache/commons/math4/ode/FirstOrderDifferentialEquations.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
 
 
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/FirstOrderIntegrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/JacobianMatrices.java b/src/main/java/org/apache/commons/math4/ode/JacobianMatrices.java
index 0ce552d..e2f3af9 100644
--- a/src/main/java/org/apache/commons/math4/ode/JacobianMatrices.java
+++ b/src/main/java/org/apache/commons/math4/ode/JacobianMatrices.java
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.lang.reflect.Array;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * This class defines a set of {@link SecondaryEquations secondary equations} to

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/MainStateJacobianProvider.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/MainStateJacobianProvider.java b/src/main/java/org/apache/commons/math4/ode/MainStateJacobianProvider.java
index 2bffbee..811a3fb 100644
--- a/src/main/java/org/apache/commons/math4/ode/MainStateJacobianProvider.java
+++ b/src/main/java/org/apache/commons/math4/ode/MainStateJacobianProvider.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
 
 /** Interface expanding {@link FirstOrderDifferentialEquations first order
  *  differential equations} in order to compute exactly the main state jacobian

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/MultistepIntegrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/MultistepIntegrator.java b/src/main/java/org/apache/commons/math4/ode/MultistepIntegrator.java
index 0fad1a2..df9797d 100644
--- a/src/main/java/org/apache/commons/math4/ode/MultistepIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/MultistepIntegrator.java
@@ -15,19 +15,19 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
-
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NoBracketingException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.linear.Array2DRowRealMatrix;
-import org.apache.commons.math3.ode.nonstiff.AdaptiveStepsizeIntegrator;
-import org.apache.commons.math3.ode.nonstiff.DormandPrince853Integrator;
-import org.apache.commons.math3.ode.sampling.StepHandler;
-import org.apache.commons.math3.ode.sampling.StepInterpolator;
-import org.apache.commons.math3.util.FastMath;
+package org.apache.commons.math4.ode;
+
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NoBracketingException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.linear.Array2DRowRealMatrix;
+import org.apache.commons.math4.ode.nonstiff.AdaptiveStepsizeIntegrator;
+import org.apache.commons.math4.ode.nonstiff.DormandPrince853Integrator;
+import org.apache.commons.math4.ode.sampling.StepHandler;
+import org.apache.commons.math4.ode.sampling.StepInterpolator;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * This class is the base class for multistep integrators for Ordinary
@@ -55,8 +55,8 @@ import org.apache.commons.math3.util.FastMath;
  * factor is therefore set to a quite low value: 2<sup>1/order</sup>.
  * </p>
  *
- * @see org.apache.commons.math3.ode.nonstiff.AdamsBashforthIntegrator
- * @see org.apache.commons.math3.ode.nonstiff.AdamsMoultonIntegrator
+ * @see org.apache.commons.math4.ode.nonstiff.AdamsBashforthIntegrator
+ * @see org.apache.commons.math4.ode.nonstiff.AdamsMoultonIntegrator
  * @since 2.0
  */
 public abstract class MultistepIntegrator extends AdaptiveStepsizeIntegrator {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/ODEIntegrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/ODEIntegrator.java b/src/main/java/org/apache/commons/math4/ode/ODEIntegrator.java
index 9efddd7..64ea0ee 100644
--- a/src/main/java/org/apache/commons/math4/ode/ODEIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/ODEIntegrator.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.util.Collection;
 
-import org.apache.commons.math3.analysis.solvers.UnivariateSolver;
-import org.apache.commons.math3.ode.events.EventHandler;
-import org.apache.commons.math3.ode.sampling.StepHandler;
+import org.apache.commons.math4.analysis.solvers.UnivariateSolver;
+import org.apache.commons.math4.ode.events.EventHandler;
+import org.apache.commons.math4.ode.sampling.StepHandler;
 
 /**
  * This interface defines the common parts shared by integrators

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/ParameterConfiguration.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/ParameterConfiguration.java b/src/main/java/org/apache/commons/math4/ode/ParameterConfiguration.java
index 7af2cd5..d71c2b7 100644
--- a/src/main/java/org/apache/commons/math4/ode/ParameterConfiguration.java
+++ b/src/main/java/org/apache/commons/math4/ode/ParameterConfiguration.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.io.Serializable;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/ParameterJacobianProvider.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/ParameterJacobianProvider.java b/src/main/java/org/apache/commons/math4/ode/ParameterJacobianProvider.java
index 911ad28..2ae8ff6 100644
--- a/src/main/java/org/apache/commons/math4/ode/ParameterJacobianProvider.java
+++ b/src/main/java/org/apache/commons/math4/ode/ParameterJacobianProvider.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
 
 /** Interface to compute exactly Jacobian matrix for some parameter
  *  when computing {@link JacobianMatrices partial derivatives equations}.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/ParameterJacobianWrapper.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/ParameterJacobianWrapper.java b/src/main/java/org/apache/commons/math4/ode/ParameterJacobianWrapper.java
index 40fcd97..856eb15 100644
--- a/src/main/java/org/apache/commons/math4/ode/ParameterJacobianWrapper.java
+++ b/src/main/java/org/apache/commons/math4/ode/ParameterJacobianWrapper.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
 
 /** Wrapper class to compute Jacobian matrices by finite differences for ODE
  *  which do not compute them by themselves.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/Parameterizable.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/Parameterizable.java b/src/main/java/org/apache/commons/math4/ode/Parameterizable.java
index 9854c7a..a424f92 100644
--- a/src/main/java/org/apache/commons/math4/ode/Parameterizable.java
+++ b/src/main/java/org/apache/commons/math4/ode/Parameterizable.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.util.Collection;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/ParameterizedODE.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/ParameterizedODE.java b/src/main/java/org/apache/commons/math4/ode/ParameterizedODE.java
index 5e5565b..9b50d65 100644
--- a/src/main/java/org/apache/commons/math4/ode/ParameterizedODE.java
+++ b/src/main/java/org/apache/commons/math4/ode/ParameterizedODE.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 
 /** Interface to compute by finite difference Jacobian matrix for some parameter

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/ParameterizedWrapper.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/ParameterizedWrapper.java b/src/main/java/org/apache/commons/math4/ode/ParameterizedWrapper.java
index 1a0bad6..14594d0 100644
--- a/src/main/java/org/apache/commons/math4/ode/ParameterizedWrapper.java
+++ b/src/main/java/org/apache/commons/math4/ode/ParameterizedWrapper.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 import java.util.ArrayList;
 import java.util.Collection;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
 
 /** Wrapper class enabling {@link FirstOrderDifferentialEquations basic simple}
  *  ODE instances to be used when processing {@link JacobianMatrices}.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/SecondOrderDifferentialEquations.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/SecondOrderDifferentialEquations.java b/src/main/java/org/apache/commons/math4/ode/SecondOrderDifferentialEquations.java
index 058860f..3061913 100644
--- a/src/main/java/org/apache/commons/math4/ode/SecondOrderDifferentialEquations.java
+++ b/src/main/java/org/apache/commons/math4/ode/SecondOrderDifferentialEquations.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
 
 /** This interface represents a second order differential equations set.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/SecondOrderIntegrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/SecondOrderIntegrator.java b/src/main/java/org/apache/commons/math4/ode/SecondOrderIntegrator.java
index 8628435..e61cc72 100644
--- a/src/main/java/org/apache/commons/math4/ode/SecondOrderIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/SecondOrderIntegrator.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalStateException;
 
 
 /** This interface represents a second order integrator for

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/SecondaryEquations.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/SecondaryEquations.java b/src/main/java/org/apache/commons/math4/ode/SecondaryEquations.java
index 358fb72..0e7e5de 100644
--- a/src/main/java/org/apache/commons/math4/ode/SecondaryEquations.java
+++ b/src/main/java/org/apache/commons/math4/ode/SecondaryEquations.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
 
 /**
  * This interface allows users to add secondary differential equations to a primary

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/UnknownParameterException.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/UnknownParameterException.java b/src/main/java/org/apache/commons/math4/ode/UnknownParameterException.java
index 172ef8c..75c6210 100644
--- a/src/main/java/org/apache/commons/math4/ode/UnknownParameterException.java
+++ b/src/main/java/org/apache/commons/math4/ode/UnknownParameterException.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Exception to be thrown when a parameter is unknown.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/events/EventFilter.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/events/EventFilter.java b/src/main/java/org/apache/commons/math4/ode/events/EventFilter.java
index c18f58e..27eab1a 100644
--- a/src/main/java/org/apache/commons/math4/ode/events/EventFilter.java
+++ b/src/main/java/org/apache/commons/math4/ode/events/EventFilter.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.events;
+package org.apache.commons.math4.ode.events;
 
 import java.util.Arrays;
 
@@ -38,7 +38,7 @@ import java.util.Arrays;
  *
  * <p>Users can wrap a regular {@link EventHandler event handler} in
  * an instance of this class and provide this wrapping instance to
- * the {@link org.apache.commons.math3.ode.FirstOrderIntegrator ODE solver}
+ * the {@link org.apache.commons.math4.ode.FirstOrderIntegrator ODE solver}
  * in order to avoid wasting time looking for uninteresting events.
  * The wrapper will intercept the calls to the {@link
  * EventHandler#g(double, double[]) g function} and to the {@link

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/events/EventHandler.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/events/EventState.java b/src/main/java/org/apache/commons/math4/ode/events/EventState.java
index 76dae72..fe3039a 100644
--- a/src/main/java/org/apache/commons/math4/ode/events/EventState.java
+++ b/src/main/java/org/apache/commons/math4/ode/events/EventState.java
@@ -15,20 +15,20 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.events;
-
-import org.apache.commons.math3.analysis.UnivariateFunction;
-import org.apache.commons.math3.analysis.solvers.AllowedSolution;
-import org.apache.commons.math3.analysis.solvers.BracketedUnivariateSolver;
-import org.apache.commons.math3.analysis.solvers.PegasusSolver;
-import org.apache.commons.math3.analysis.solvers.UnivariateSolver;
-import org.apache.commons.math3.analysis.solvers.UnivariateSolverUtils;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NoBracketingException;
-import org.apache.commons.math3.ode.EquationsMapper;
-import org.apache.commons.math3.ode.ExpandableStatefulODE;
-import org.apache.commons.math3.ode.sampling.StepInterpolator;
-import org.apache.commons.math3.util.FastMath;
+package org.apache.commons.math4.ode.events;
+
+import org.apache.commons.math4.analysis.UnivariateFunction;
+import org.apache.commons.math4.analysis.solvers.AllowedSolution;
+import org.apache.commons.math4.analysis.solvers.BracketedUnivariateSolver;
+import org.apache.commons.math4.analysis.solvers.PegasusSolver;
+import org.apache.commons.math4.analysis.solvers.UnivariateSolver;
+import org.apache.commons.math4.analysis.solvers.UnivariateSolverUtils;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NoBracketingException;
+import org.apache.commons.math4.ode.EquationsMapper;
+import org.apache.commons.math4.ode.ExpandableStatefulODE;
+import org.apache.commons.math4.ode.sampling.StepInterpolator;
+import org.apache.commons.math4.util.FastMath;
 
 /** This class handles the state for one {@link EventHandler
  * event handler} during integration steps.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/events/FilterType.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/events/Transformer.java b/src/main/java/org/apache/commons/math4/ode/events/Transformer.java
index 5c1f97c..f341f35 100644
--- a/src/main/java/org/apache/commons/math4/ode/events/Transformer.java
+++ b/src/main/java/org/apache/commons/math4/ode/events/Transformer.java
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.events;
+package org.apache.commons.math4.ode.events;
 
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.Precision;
 
 
 /** Transformer for {@link EventHandler#g(double, double[]) g functions}.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/events/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/events/package-info.java b/src/main/java/org/apache/commons/math4/ode/events/package-info.java
index 9d3b917..6e8ecdd 100644
--- a/src/main/java/org/apache/commons/math4/ode/events/package-info.java
+++ b/src/main/java/org/apache/commons/math4/ode/events/package-info.java
@@ -23,7 +23,7 @@
  *
  * <p>
  * Discrete events detection is based on switching functions. The user provides
- * a simple {@link org.apache.commons.math3.ode.events.EventHandler#g g(t, y)}
+ * a simple {@link org.apache.commons.math4.ode.events.EventHandler#g g(t, y)}
  * function depending on the current time and state. The integrator will monitor
  * the value of the function throughout integration range and will trigger the
  * event when its sign changes. The magnitude of the value is almost irrelevant,
@@ -93,4 +93,4 @@
  *
  *
  */
-package org.apache.commons.math3.ode.events;
+package org.apache.commons.math4.ode.events;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsBashforthIntegrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsBashforthIntegrator.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsBashforthIntegrator.java
index fd80d85..2623756 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsBashforthIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsBashforthIntegrator.java
@@ -15,17 +15,17 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
-
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NoBracketingException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.linear.Array2DRowRealMatrix;
-import org.apache.commons.math3.ode.EquationsMapper;
-import org.apache.commons.math3.ode.ExpandableStatefulODE;
-import org.apache.commons.math3.ode.sampling.NordsieckStepInterpolator;
-import org.apache.commons.math3.util.FastMath;
+package org.apache.commons.math4.ode.nonstiff;
+
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NoBracketingException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.linear.Array2DRowRealMatrix;
+import org.apache.commons.math4.ode.EquationsMapper;
+import org.apache.commons.math4.ode.ExpandableStatefulODE;
+import org.apache.commons.math4.ode.sampling.NordsieckStepInterpolator;
+import org.apache.commons.math4.util.FastMath;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsIntegrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsIntegrator.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsIntegrator.java
index dd6f2a1..9563d31 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsIntegrator.java
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
+package org.apache.commons.math4.ode.nonstiff;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NoBracketingException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.linear.Array2DRowRealMatrix;
-import org.apache.commons.math3.ode.ExpandableStatefulODE;
-import org.apache.commons.math3.ode.MultistepIntegrator;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NoBracketingException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.linear.Array2DRowRealMatrix;
+import org.apache.commons.math4.ode.ExpandableStatefulODE;
+import org.apache.commons.math4.ode.MultistepIntegrator;
 
 
 /** Base class for {@link AdamsBashforthIntegrator Adams-Bashforth} and

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsMoultonIntegrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsMoultonIntegrator.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsMoultonIntegrator.java
index c019fab..dc58b6c 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsMoultonIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsMoultonIntegrator.java
@@ -15,20 +15,20 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
+package org.apache.commons.math4.ode.nonstiff;
 
 import java.util.Arrays;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NoBracketingException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.linear.Array2DRowRealMatrix;
-import org.apache.commons.math3.linear.RealMatrixPreservingVisitor;
-import org.apache.commons.math3.ode.EquationsMapper;
-import org.apache.commons.math3.ode.ExpandableStatefulODE;
-import org.apache.commons.math3.ode.sampling.NordsieckStepInterpolator;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NoBracketingException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.linear.Array2DRowRealMatrix;
+import org.apache.commons.math4.linear.RealMatrixPreservingVisitor;
+import org.apache.commons.math4.ode.EquationsMapper;
+import org.apache.commons.math4.ode.ExpandableStatefulODE;
+import org.apache.commons.math4.ode.sampling.NordsieckStepInterpolator;
+import org.apache.commons.math4.util.FastMath;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsNordsieckTransformer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsNordsieckTransformer.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsNordsieckTransformer.java
index 68f66c6..a648ce2 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsNordsieckTransformer.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdamsNordsieckTransformer.java
@@ -15,22 +15,22 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
+package org.apache.commons.math4.ode.nonstiff;
 
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.commons.math3.fraction.BigFraction;
-import org.apache.commons.math3.linear.Array2DRowFieldMatrix;
-import org.apache.commons.math3.linear.Array2DRowRealMatrix;
-import org.apache.commons.math3.linear.ArrayFieldVector;
-import org.apache.commons.math3.linear.FieldDecompositionSolver;
-import org.apache.commons.math3.linear.FieldLUDecomposition;
-import org.apache.commons.math3.linear.FieldMatrix;
-import org.apache.commons.math3.linear.MatrixUtils;
-import org.apache.commons.math3.linear.QRDecomposition;
-import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math4.fraction.BigFraction;
+import org.apache.commons.math4.linear.Array2DRowFieldMatrix;
+import org.apache.commons.math4.linear.Array2DRowRealMatrix;
+import org.apache.commons.math4.linear.ArrayFieldVector;
+import org.apache.commons.math4.linear.FieldDecompositionSolver;
+import org.apache.commons.math4.linear.FieldLUDecomposition;
+import org.apache.commons.math4.linear.FieldMatrix;
+import org.apache.commons.math4.linear.MatrixUtils;
+import org.apache.commons.math4.linear.QRDecomposition;
+import org.apache.commons.math4.linear.RealMatrix;
 
 /** Transformer to Nordsieck vectors for Adams integrators.
  * <p>This class is used by {@link AdamsBashforthIntegrator Adams-Bashforth} and

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/AdaptiveStepsizeIntegrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaIntegrator.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaIntegrator.java
index ca915f1..e6df204 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaIntegrator.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
+package org.apache.commons.math4.ode.nonstiff;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaStepInterpolator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaStepInterpolator.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaStepInterpolator.java
index ba9b11f..1f60963 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaStepInterpolator.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaStepInterpolator.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
+package org.apache.commons.math4.ode.nonstiff;
 
-import org.apache.commons.math3.ode.sampling.StepInterpolator;
+import org.apache.commons.math4.ode.sampling.StepInterpolator;
 
 /**
  * This class implements a step interpolator for the classical fourth

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54Integrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54Integrator.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54Integrator.java
index 45229b2..731ea93 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54Integrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54Integrator.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
+package org.apache.commons.math4.ode.nonstiff;
 
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.util.FastMath;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54StepInterpolator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54StepInterpolator.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54StepInterpolator.java
index a013584..114ce48 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54StepInterpolator.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince54StepInterpolator.java
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
+package org.apache.commons.math4.ode.nonstiff;
 
-import org.apache.commons.math3.ode.AbstractIntegrator;
-import org.apache.commons.math3.ode.EquationsMapper;
-import org.apache.commons.math3.ode.sampling.StepInterpolator;
+import org.apache.commons.math4.ode.AbstractIntegrator;
+import org.apache.commons.math4.ode.EquationsMapper;
+import org.apache.commons.math4.ode.sampling.StepInterpolator;
 
 /**
  * This class represents an interpolator over the last step during an

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince853Integrator.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince853Integrator.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince853Integrator.java
index 895cb88..841d894 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince853Integrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/DormandPrince853Integrator.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
+package org.apache.commons.math4.ode.nonstiff;
 
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.util.FastMath;
 
 
 /**
diff --git a/src/main/java/org/apache/commons/math4/ode/FirstOrderIntegrator.java b/src/main/java/org/apache/commons/math4/ode/FirstOrderIntegrator.java
index 945aea8..3ac874e 100644
--- a/src/main/java/org/apache/commons/math4/ode/FirstOrderIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/FirstOrderIntegrator.java
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode;
+package org.apache.commons.math4.ode;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NoBracketingException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NoBracketingException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
 
 /** This interface represents a first order integrator for
  * differential equations.
@@ -31,8 +31,8 @@ import org.apache.commons.math3.exception.NumberIsTooSmallException;
  * FirstOrderDifferentialEquations} interface.</p>
  *
  * @see FirstOrderDifferentialEquations
- * @see org.apache.commons.math3.ode.sampling.StepHandler
- * @see org.apache.commons.math3.ode.events.EventHandler
+ * @see org.apache.commons.math4.ode.sampling.StepHandler
+ * @see org.apache.commons.math4.ode.events.EventHandler
  * @since 1.2
  */
 
@@ -52,7 +52,7 @@ public interface FirstOrderIntegrator extends ODEIntegrator {
    *  step (and hence at the end of integration), can be the same object as y0
    * @return stop time, will be the same as target time if integration reached its
    * target, but may be different if some {@link
    * org.apache.commons.math3.ode.events.EventHandler} stops it at some point.
    * @exception DimensionMismatchException if arrays dimension do not match equations settings
    * @exception NumberIsTooSmallException if integration step is too small
    * @exception MaxCountExceededException if the number of functions evaluations is exceeded

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/JacobianMatrices.java
----------------------------------------------------------------------
@@ -52,7 +52,7 @@ public interface FirstOrderIntegrator extends ODEIntegrator {
    * @return stop time, will be the same as target time if integration reached its
    * target, but may be different if some {@link
-   * org.apache.commons.math3.ode.events.EventHandler} stops it at some point.
+   * org.apache.commons.math4.ode.events.EventHandler} stops it at some point.
    * @exception DimensionMismatchException if arrays dimension do not match equations settings
    * @exception NumberIsTooSmallException if integration step is too small
diff --git a/src/main/java/org/apache/commons/math4/ode/events/EventHandler.java b/src/main/java/org/apache/commons/math4/ode/events/EventHandler.java
index 8fb39a4..cb22ea1 100644
--- a/src/main/java/org/apache/commons/math4/ode/events/EventHandler.java
+++ b/src/main/java/org/apache/commons/math4/ode/events/EventHandler.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.events;
+package org.apache.commons.math4.ode.events;
 
 
 /** This interface represents a handler for discrete events triggered
@@ -73,7 +73,7 @@ public interface EventHandler  {
          * #eventOccurred eventOccurred} method when the integration should
          * go on after the event ending the current step, with a new derivatives
          * vector (which will be retrieved thanks to the {@link
-         * org.apache.commons.math3.ode.FirstOrderDifferentialEquations#computeDerivatives}
+         * org.apache.commons.math4.ode.FirstOrderDifferentialEquations#computeDerivatives}
          * method).</p>
          */
         RESET_DERIVATIVES,
@@ -111,7 +111,7 @@ public interface EventHandler  {
    * the sign of the switching function at the start of the next step (i.e.
    * just after the event) is the opposite of the sign just before the event.
    * This consistency between the steps <string>must</strong> be preserved,
-   * otherwise {@link org.apache.commons.math3.exception.NoBracketingException
+   * otherwise {@link org.apache.commons.math4.exception.NoBracketingException
    * exceptions} related to root not being bracketed will occur.</p>
    * <p>This need for consistency is sometimes tricky to achieve. A typical
    * example is using an event to model a ball bouncing on the floor. The first
@@ -143,7 +143,7 @@ public interface EventHandler  {
    * the step handler itself is called (see below for scheduling). It
    * allows the user to update his internal data to acknowledge the fact
    * the event has been handled (for example setting a flag in the {@link
-   * org.apache.commons.math3.ode.FirstOrderDifferentialEquations
+   * org.apache.commons.math4.ode.FirstOrderDifferentialEquations
    * differential equations} to switch the derivatives computation in
    * case of discontinuity), or to direct the integrator to either stop
    * or continue integration, possibly with a reset state or derivatives.</p>
@@ -151,7 +151,7 @@ public interface EventHandler  {
    * <ul>
    *   <li>if {@link Action#STOP} is returned, the step handler will be called
    *   with the <code>isLast</code> flag of the {@link
-   *   org.apache.commons.math3.ode.sampling.StepHandler#handleStep handleStep}
+   *   org.apache.commons.math4.ode.sampling.StepHandler#handleStep handleStep}
    *   method set to true and the integration will be stopped,</li>
    *   <li>if {@link Action#RESET_STATE} is returned, the {@link #resetState
    *   resetState} method will be called once the step handler has
@@ -165,28 +165,28 @@ public interface EventHandler  {
    * </ul>
 
    * <p>The scheduling between this method and the {@link
    * org.apache.commons.math3.ode.sampling.StepHandler StepHandler} method {@link
    * org.apache.commons.math3.ode.sampling.StepHandler#handleStep(
    * org.apache.commons.math3.ode.sampling.StepInterpolator, boolean)
    * handleStep(interpolator, isLast)} is to call this method first and
    * <code>handleStep</code> afterwards. This scheduling allows the integrator to
    * pass <code>true</code> as the <code>isLast</code> parameter to the step
    * handler to make it aware the step will be the last one if this method
    * returns {@link Action#STOP}. As the interpolator may be used to navigate back
    * throughout the last step (as {@link
-   * org.apache.commons.math3.ode.sampling.StepNormalizer StepNormalizer}
+   * org.apache.commons.math4.ode.sampling.StepNormalizer StepNormalizer}
    * does for example), user code called by this method and user
    * code called by step handlers may experience apparently out of order values
    * of the independent time variable. As an example, if the same user object
    * implements both this {@link EventHandler EventHandler} interface and the
-   * {@link org.apache.commons.math3.ode.sampling.FixedStepHandler FixedStepHandler}
+   * {@link org.apache.commons.math4.ode.sampling.FixedStepHandler FixedStepHandler}
    * interface, a <em>forward</em> integration may call its
    * <code>eventOccurred</code> method with t = 10 first and call its
    * <code>handleStep</code> method with t = 9 afterwards. Such out of order
    * calls are limited to the size of the integration step for {@link
    * org.apache.commons.math3.ode.sampling.StepHandler variable step handlers} and
    * to the size of the fixed step for {@link
    * org.apache.commons.math3.ode.sampling.FixedStepHandler fixed step handlers}.</p>
 
    * @param t current value of the independent <i>time</i> variable
    * @param y array containing the current value of the state vector

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/events/EventState.java
----------------------------------------------------------------------
@@ -165,28 +165,28 @@ public interface EventHandler  {
 
    * <p>The scheduling between this method and the {@link
-   * org.apache.commons.math3.ode.sampling.StepHandler StepHandler} method {@link
-   * org.apache.commons.math3.ode.sampling.StepHandler#handleStep(
-   * org.apache.commons.math3.ode.sampling.StepInterpolator, boolean)
+   * org.apache.commons.math4.ode.sampling.StepHandler StepHandler} method {@link
+   * org.apache.commons.math4.ode.sampling.StepHandler#handleStep(
+   * org.apache.commons.math4.ode.sampling.StepInterpolator, boolean)
    * handleStep(interpolator, isLast)} is to call this method first and
    * <code>handleStep</code> afterwards. This scheduling allows the integrator to
@@ -165,28 +165,28 @@ public interface EventHandler  {
    * <code>handleStep</code> method with t = 9 afterwards. Such out of order
    * calls are limited to the size of the integration step for {@link
-   * org.apache.commons.math3.ode.sampling.StepHandler variable step handlers} and
+   * org.apache.commons.math4.ode.sampling.StepHandler variable step handlers} and
    * to the size of the fixed step for {@link
@@ -165,28 +165,28 @@ public interface EventHandler  {
    * to the size of the fixed step for {@link
-   * org.apache.commons.math3.ode.sampling.FixedStepHandler fixed step handlers}.</p>
+   * org.apache.commons.math4.ode.sampling.FixedStepHandler fixed step handlers}.</p>
 
    * @param t current value of the independent <i>time</i> variable
diff --git a/src/main/java/org/apache/commons/math4/ode/events/FilterType.java b/src/main/java/org/apache/commons/math4/ode/events/FilterType.java
index 2ac0df8..4dfaefb 100644
--- a/src/main/java/org/apache/commons/math4/ode/events/FilterType.java
+++ b/src/main/java/org/apache/commons/math4/ode/events/FilterType.java
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.events;
+package org.apache.commons.math4.ode.events;
 
-import org.apache.commons.math3.exception.MathInternalError;
+import org.apache.commons.math4.exception.MathInternalError;
 
 /** Enumerate for {@link EventFilter filtering events}.
  *
@@ -83,7 +83,7 @@ public enum FilterType {
          *   <li>h = min(-s,-g,+g)</li>
          *   <li>h = -g</li>
          * </ul>
          * where s is a tiny positive value: {@link org.apache.commons.math3.util.Precision#SAFE_MIN}.
          * </p>
          */
         @Override
@@ -261,7 +261,7 @@ public enum FilterType {
          *   <li>h = min(-s,-g,+g)</li>
          *   <li>h = -g</li>
          * </ul>
          * where s is a tiny positive value: {@link org.apache.commons.math3.util.Precision#SAFE_MIN}.
          * </p>
          */
         @Override

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/events/Transformer.java
----------------------------------------------------------------------
@@ -83,7 +83,7 @@ public enum FilterType {
          *   <li>h = -g</li>
          * </ul>
-         * where s is a tiny positive value: {@link org.apache.commons.math3.util.Precision#SAFE_MIN}.
+         * where s is a tiny positive value: {@link org.apache.commons.math4.util.Precision#SAFE_MIN}.
          * </p>
          */
@@ -261,7 +261,7 @@ public enum FilterType {
          *   <li>h = -g</li>
          * </ul>
-         * where s is a tiny positive value: {@link org.apache.commons.math3.util.Precision#SAFE_MIN}.
+         * where s is a tiny positive value: {@link org.apache.commons.math4.util.Precision#SAFE_MIN}.
          * </p>
          */
diff --git a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdaptiveStepsizeIntegrator.java b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdaptiveStepsizeIntegrator.java
index ab79bbf..6dacc1a 100644
--- a/src/main/java/org/apache/commons/math4/ode/nonstiff/AdaptiveStepsizeIntegrator.java
+++ b/src/main/java/org/apache/commons/math4/ode/nonstiff/AdaptiveStepsizeIntegrator.java
@@ -15,16 +15,16 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.ode.nonstiff;
+package org.apache.commons.math4.ode.nonstiff;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NoBracketingException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.ode.AbstractIntegrator;
-import org.apache.commons.math3.ode.ExpandableStatefulODE;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NoBracketingException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.ode.AbstractIntegrator;
+import org.apache.commons.math4.ode.ExpandableStatefulODE;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * This abstract class holds the common part of all adaptive
@@ -44,7 +44,7 @@ import org.apache.commons.math3.util.FastMath;
  * <p>
  * If the Ordinary Differential Equations is an {@link ExpandableStatefulODE
  * extended ODE} rather than a {@link
  * org.apache.commons.math3.ode.FirstOrderDifferentialEquations basic ODE}, then
  * <em>only</em> the {@link ExpandableStatefulODE#getPrimaryState() primary part}
  * of the state vector is used for stepsize control, not the complete state vector.
  * </p>

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/ode/nonstiff/ClassicalRungeKuttaIntegrator.java
----------------------------------------------------------------------
@@ -44,7 +44,7 @@ import org.apache.commons.math3.util.FastMath;
  * If the Ordinary Differential Equations is an {@link ExpandableStatefulODE
  * extended ODE} rather than a {@link
- * org.apache.commons.math3.ode.FirstOrderDifferentialEquations basic ODE}, then
+ * org.apache.commons.math4.ode.FirstOrderDifferentialEquations basic ODE}, then
  * <em>only</em> the {@link ExpandableStatefulODE#getPrimaryState() primary part}
  * of the state vector is used for stepsize control, not the complete state vector.